@@ -1,4 +1,5 @@
 import re
+import warnings
 def get_start_end_index(achievement, rel_string, case_insensitive=False):
     rel_string = rel_string.strip()
     if case_insensitive:
@@ -6,7 +7,7 @@ def get_start_end_index(achievement, rel_string, case_insensitive=False):
     else:
         matched = re.search(rel_string, achievement)
     if matched is None:
-        raise ValueError(rel_string + "\nnot found in: \n" + achievement)
+        warnings.warn(rel_string + "\nnot found in: \n" + achievement)
     return {"start_index": matched.regs[0][0], "end_index": matched.regs[0][1], "repl": rel_string}
 
 def get_all_start_end_indexes(original_text: str, to_replace: list,
