@@ -193,9 +193,9 @@ class Viewer(DocUtilsMixin):
                 values_to_highlight = []
                 for j, highlight_field in enumerate(highlight):
                     values_to_highlight.extend(json[highlight_field])
-                start_highlighter_hooks = [
+                    start_highlighter_hooks = [
                     self.get_highlight_header(highlight_colors[j]) \
-                    for j in range(len(values_to_highlight))]
+                    for v in range(len(values_to_highlight))]
                 output_highlight_value.append(inject_strings(
                     value_to_highlight, 
                     values_to_highlight, 
